(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10044,        300]*)
(*NotebookOutlinePosition[     11264,        341]*)
(*  CellTagsIndexPosition[     11116,        333]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Large Scale Linear Programming", "Section",
  CellTags->"DenseLinearAlgebra"],

Cell[TextData[{
  "MPS is a data format for linear programming problems which can be imported \
into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0."
}], "Text"],

Cell["\<\
Load a package which, though not needed to import MPS files, puts the data in \
a special data structure and adds rules so that LinearProgramming can use it \
directly.\
\>", "MathCaption"],

Cell[BoxData[
    \(Needs["\<Optimization`MPSData`\>"]\)], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
This imports an MPS file containing data from the 80BAU3B problem.\
\>", "MathCaption"],

Cell[BoxData[
    \(mpsdata\  = \ Import["\<80bau3b.mps\>", \ "\<MPSData\>"\ ]\)], "Input",
  CellLabel->"In[35]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
The problem has nearly 10000 variables with over 2000 constraints.\
\>", "Text"],

Cell["This solves the problem.", "MathCaption"],

Cell[BoxData[
    \(Timing[Short[xopt\  = \ LinearProgramming[mpsdata]]]\)], "Input",
  CellLabel->"In[39]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
This puts the data into the arguments you could give to LinearProgramming and \
computes the optimal value of the objective function.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\({c, \ A, \ b, \ d}\  = \ 
        ToLinearProgrammingData[mpsdata];\)\), "\[IndentingNewLine]", 
    \(c . xopt\)}], "Input",
  CellLabel->"In[40]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  "There is also a new ",
  StyleBox["DualLinearProgramming", "MR"],
  " command which gives you information about the dual along with the \
result."
}], "MathCaption"],

Cell[BoxData[
    \(Timing[\(DualLinearProgramming[c, \ A, \ b, \ d];\)]\)], "Input",
  CellLabel->"In[44]:="],

Cell["", "Text",
  CellOpen->False,
  CellTags->{"PlatformSupport", "LastSlide"}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DenseLinearAlgebra"->{
    Cell[3373, 96, 83, 1, 76, "Section",
      CellTags->"DenseLinearAlgebra"]},
  "PlatformSupport"->{
    Cell[9947, 295, 81, 2, 28, "Text",
      CellOpen->False,
      CellTags->{"PlatformSupport", "LastSlide"}]},
  "LastSlide"->{
    Cell[9947, 295, 81, 2, 28, "Text",
      CellOpen->False,
      CellTags->{"PlatformSupport", "LastSlide"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DenseLinearAlgebra", 10742, 318},
  {"PlatformSupport", 10846, 321},
  {"LastSlide", 10977, 325}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1594, 41, 20, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[3373, 96, 83, 1, 76, "Section",
  CellTags->"DenseLinearAlgebra"],
Cell[3459, 99, 177, 6, 37, "Text"],
Cell[3639, 107, 199, 4, 65, "MathCaption"],
Cell[3841, 113, 92, 2, 51, "Input"],
Cell[3936, 117, 97, 2, 43, "MathCaption"],
Cell[4036, 121, 116, 2, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4189, 128, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[5786, 171, 90, 2, 37, "Text"],
Cell[5879, 175, 47, 0, 43, "MathCaption"],
Cell[5929, 177, 110, 2, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6076, 184, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[7673, 227, 164, 3, 65, "MathCaption"],
Cell[7840, 232, 173, 4, 77, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8050, 241, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[9647, 284, 184, 5, 66, "MathCaption"],
Cell[9834, 291, 110, 2, 40, "Input"],
Cell[9947, 295, 81, 2, 28, "Text",
  CellOpen->False,
  CellTags->{"PlatformSupport", "LastSlide"}]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

