(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16669,        498]*)
(*NotebookOutlinePosition[     17891,        539]*)
(*  CellTagsIndexPosition[     17743,        531]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Reduce", "Section",
  CellTags->"DenseLinearAlgebra"],

Cell[TextData[{
  "Consider solving the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 - 2  y\^2 \[Equal] 1\)]],
  " over different domains. In all cases there are infinitely many solutions. \
In the case of complexes and reals, we can use earlier variables in the \
variable list to parametrize later ones. However in the case of Diophantine \
equations that is no longer enough, but we need to generate additional \
parameters to fully describe the solutions. "
}], "Text"],

Cell[BoxData[
    \(Clear[x, y, z, a, b, c, \ n]\)], "Input",
  CellLabel->"In[94]:="],

Cell["Solving a simple equation over the complexes. ", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ x\^2 - 2\ y\^2 \[Equal] 1, \ {x, y}, \ Complexes\ ]\)], "Input",\

  CellLabel->"In[49]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
Solving the same equation over the reals, requires inequalities to describe \
the solution.\
\>", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ x\^2 - 2  y\^2 \[Equal] 1, \ {x, y}, \ Reals\ ]\)], "Input",
  CellLabel->"In[50]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
Solving the same equation over the integers in addition requires parameters \
to describe the solution.\
\>", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ 
      Integers\ ]\)], "Input",
  CellLabel->"In[51]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["This solves the equation over the integers modulo 12.", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ 
      Modulus\  \[Rule] \ 12\ ]\)], "Input",
  CellLabel->"In[52]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
You can also solve over mixed domains. You will then need to add the domain \
equations along with your ordinary equations. \
\>", "Text"],

Cell["\<\
Solving the same equation over the mixed reals and complexes. \
\>", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ 
      x\^2 - 2  y\^2 \[Equal] 1\  && \ x \[Element] Reals\  && \ 
        y \[Element] Complexes, \ {x, y}\ ]\)], "Input",
  CellLabel->"In[53]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["Reduce will generate complete solution sets.", "Text"],

Cell["\<\
In this case there is countably infinitely many complex roots, a single real \
root and no integer roots. \
\>", "MathCaption"],

Cell[BoxData[
    \(Reduce[\ 
      5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\)\  && \ x \[Element] Complexes, \ 
      x\ ]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(Reduce[\ 5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\) && x \[Element] Reals, \ 
      x\ ]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(Reduce[\ 
      5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\) && x \[Element] Integers, \ 
      x\ ]\)], "Input",
  CellLabel->"In[56]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  "Another type of problem is one that includes quantifiers, such as \
existential (",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \)]],
  ") or universal (",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \)]],
  ") quanfiers. "
}], "Text"],

Cell[TextData[{
  "This reduces the values for ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " that make the quadratic polynomial positive for all real ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "MathCaption"],

Cell[BoxData[
    \(Reduce[\ 
      ForAll[\ x, \ x \[Element] Reals, \ 
        x\^2 + \ a\ x\  + \ b \[GreaterEqual] 0\ ], \ {a, b}, \ 
      Reals\ ]\)], "Input",
  CellLabel->"In[59]:="],

Cell["", "Text",
  CellOpen->False,
  CellTags->{"PlatformSupport", "LastSlide"}]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DenseLinearAlgebra"->{
    Cell[3373, 96, 59, 1, 76, "Section",
      CellTags->"DenseLinearAlgebra"]},
  "PlatformSupport"->{
    Cell[16572, 493, 81, 2, 28, "Text",
      CellOpen->False,
      CellTags->{"PlatformSupport", "LastSlide"}]},
  "LastSlide"->{
    Cell[16572, 493, 81, 2, 28, "Text",
      CellOpen->False,
      CellTags->{"PlatformSupport", "LastSlide"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DenseLinearAlgebra", 17367, 516},
  {"PlatformSupport", 17471, 519},
  {"LastSlide", 17603, 523}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1594, 41, 20, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[3373, 96, 59, 1, 76, "Section",
  CellTags->"DenseLinearAlgebra"],
Cell[3435, 99, 486, 9, 112, "Text"],
Cell[3924, 110, 86, 2, 51, "Input"],
Cell[4013, 114, 69, 0, 43, "MathCaption"],
Cell[4085, 116, 120, 3, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4242, 124, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[5839, 167, 122, 3, 43, "MathCaption"],
Cell[5964, 172, 114, 2, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6115, 179, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[7712, 222, 134, 3, 43, "MathCaption"],
Cell[7849, 227, 126, 3, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8012, 235, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[9609, 278, 76, 0, 43, "MathCaption"],
Cell[9688, 280, 140, 3, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9865, 288, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[11462, 331, 148, 3, 62, "Text"],
Cell[11613, 336, 93, 2, 43, "MathCaption"],
Cell[11709, 340, 177, 4, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11923, 349, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[13520, 392, 60, 0, 37, "Text"],
Cell[13583, 394, 137, 3, 43, "MathCaption"],
Cell[13723, 399, 156, 4, 52, "Input"],
Cell[13882, 405, 141, 3, 52, "Input"],
Cell[14026, 410, 151, 4, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14214, 419, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[15811, 462, 268, 9, 37, "Text"],
Cell[16082, 473, 294, 11, 43, "MathCaption"],
Cell[16379, 486, 190, 5, 46, "Input"],
Cell[16572, 493, 81, 2, 28, "Text",
  CellOpen->False,
  CellTags->{"PlatformSupport", "LastSlide"}]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

